Multiple-precision Complex
==========================

.. currentmodule:: gmpy2

mpc Type
--------

.. autoclass:: mpc
   :special-members: __format__

mpc Functions
-------------

.. autofunction:: acos
.. autofunction:: acosh
.. autofunction:: asin
.. autofunction:: asinh
.. autofunction:: atan
.. autofunction:: atanh
.. autofunction:: cos
.. autofunction:: cosh
.. autofunction:: div_2exp
.. autofunction:: exp
.. autofunction:: is_nan
.. autofunction:: is_zero
.. autofunction:: log
.. autofunction:: log10
.. autofunction:: mpc_random
.. autofunction:: mul_2exp
.. autofunction:: norm
.. autofunction:: phase
.. autofunction:: polar
.. autofunction:: proj
.. autofunction:: rect
.. autofunction:: root_of_unity
.. autofunction:: sin
.. autofunction:: sin_cos
.. autofunction:: sinh
.. autofunction:: sqrt
.. autofunction:: tan
.. autofunction:: tanh
